/*  aKode: Player class

    Copyright (C) 2004 Allan Sandfeld Jensen <kde@carewolf.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

#ifndef _AKODE_PLAYER_H
#define _AKODE_PLAYER_H

#include <string>
using std::string;

namespace aKode {

class File;
class Sink;
class Decoder;
class Resampler;

//! An implementation of a multithreaded aKode-player

/*!
 */
class Player {
public:
    Player();
    ~Player();

    bool open(string sinkname);
    void close();

    bool load(string filename);
    void unload();

    void play();
    void pause();
    void stop();
    
    void setVolume(float v);
    float volume() const;

    File* file() const;
    Sink* sink() const;
    Decoder* decoder() const;
    Resampler* resampler() const;

    enum State { Closed  = 0,
                 Open    = 2,
                 Loaded  = 4,
                 Playing = 8,
                 Paused  = 12 };

    State state() const;

    struct private_data;
private:
    private_data *m_data;
    void setState(State state);
};

} // namespace

#endif
